# Copyright(C) 2004 Tiago Cogumbreiro <cogumbreiro@users.sf.net>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or(at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
#
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#
# Authors: Matthew Martin <xfceslacker@gmail.com>,
#          Tiago Cogumbreiro <cogumbreiro@users.sf.net>

import dbus
from gettext import gettext as _


GNOME = dict(object_name='org.gnome.PowerManager',
             object_path='/org/gnome/PowerManager',
             interface='org.gnome.PowerManager')

FDO = dict(object_name='org.freedesktop.PowerManagement',
           object_path='/org/freedesktop/PowerManagement/Inhibit',
           interface='org.freedesktop.PowerManagement.Inhibit')

SPECS = (GNOME, FDO)

class InhibitSuspend(object):
    """
    Plugin to enable power inhibiting while writing an audio disc.
    """
    def __init__(self):
        bus = dbus.Bus(dbus.Bus.TYPE_SESSION)
        for spec in SPECS:
            try:
                obj = bus.get_object(spec['object_name'],
                                     spec['object_path'])
                iface = dbus.Interface(obj, spec['interface'])
                self.inhibit = iface.Inhibit
                self.uninhibit = iface.UnInhibit
                break
            except dbus.DBusException:
                pass
        else:
            self.inhibit = lambda *args: None
            self.uninhibit = self.inhibit

    def on_writing_started(self, app):
        self.cookie = self.inhibit('Serpentine', _('Writing audio disc'))
    
    def on_writing_finished(self, app):
        self.uninhibit(self.cookie)


def create_plugin(app):
    inhibit = InhibitSuspend()
    app.add_listener(inhibit)
    
